<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Odbiorcy Edit Form");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Odbiorcy Edit Form");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "formularz Page");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Możesz ustawić więcej niż jednego odbiorcy, oddzielając e-maile przecinkami.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Zapisywanie odbiorcy ...");
define('VIEW_FORM_TABLES_HEADING', "Zobacz tabele formularzy");
define('VIEW_FORM_TABLES_BTN', "Zobacz tabele formularzy");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Wybierz tabele do wyświetlenia");
define('VIEW_FORM_TABLES_FILTER_READ', "Filtruj przeczytane wiadomości");
?>